/*
 * Licensed to Crate under one or more contributor license agreements.
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.  Crate licenses this file
 * to you under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.  You may
 * obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied.  See the License for the specific language governing
 * permissions and limitations under the License.
 *
 * However, if you have executed another commercial license agreement
 * with Crate these terms will supersede the license and you may use the
 * software solely pursuant to the terms of the relevant commercial
 * agreement.
 */

package io.crate.executor.transport;

import io.crate.analyze.symbol.SelectSymbol;
import io.crate.planner.MultiPhasePlan;
import io.crate.planner.node.dql.ESGet;
import io.crate.test.integration.CrateUnitTest;
import io.crate.testing.SQLExecutor;
import org.apache.lucene.util.BytesRef;
import org.elasticsearch.test.cluster.NoopClusterService;
import org.junit.Test;

import static io.crate.testing.SymbolMatchers.isLiteral;
import static org.hamcrest.Matchers.contains;

public class SubSelectSymbolReplacerTest extends CrateUnitTest {

    private SQLExecutor e = SQLExecutor.builder(new NoopClusterService()).enableDefaultTables().build();

    @Test
    public void testSelectSymbolsAreReplacedInSelectListOfPrimaryKeyLookups() throws Exception {
        MultiPhasePlan plan = e.plan("select (select 'foo' from sys.cluster) from users where id = 10");
        ESGet esGet = (ESGet) plan.rootPlan();
        SelectSymbol subSelect = (SelectSymbol) esGet.outputs().get(0);

        SubSelectSymbolReplacer replacer = new SubSelectSymbolReplacer(esGet, subSelect);
        replacer.onSuccess(new BytesRef("foo"));

        assertThat(esGet.outputs(), contains(isLiteral("foo")));
    }
}
