/*
 * Licensed to Crate under one or more contributor license agreements.
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.  Crate licenses this file
 * to you under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.  You may
 * obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
 * implied.  See the License for the specific language governing
 * permissions and limitations under the License.
 *
 * However, if you have executed another commercial license agreement
 * with Crate these terms will supersede the license and you may use the
 * software solely pursuant to the terms of the relevant commercial
 * agreement.
 */

package io.crate.planner;

import com.google.common.collect.ImmutableList;
import io.crate.planner.fetch.IndexBaseVisitor;
import org.junit.Test;

import java.util.TreeMap;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;

public class IndexBaseVisitorTest {

    @Test
    public void testDoubleIndex() throws Exception {
        IndexBaseVisitor visitor = new IndexBaseVisitor();

        visitor.visitIndex("n1", "i1", ImmutableList.of(1, 4));
        visitor.visitIndex("n1", "i2", ImmutableList.of(1, 2));
        visitor.visitIndex("n2", "i1", ImmutableList.of(1, 5));
        visitor.visitIndex("n3", "i1", ImmutableList.of(1, 3));
        visitor.visitIndex("n3", "i3", ImmutableList.of(1, 3));

        TreeMap<String, Integer> bases = visitor.build();
        assertThat(bases.size(), is(3));
        assertThat(bases.get("i1"), is(0));
        assertThat(bases.get("i2"), is(6));
        assertThat(bases.get("i3"), is(9));
    }

    @Test
    public void testMaxShard() throws Exception {
        IndexBaseVisitor visitor = new IndexBaseVisitor();

        visitor.visitIndex("n1", "i1", ImmutableList.of(1, 4));
        visitor.visitIndex("n2", "i2", ImmutableList.of(1, 5));
        TreeMap<String, Integer> bases = visitor.build();
        assertThat(bases.size(), is(2));
        assertThat(bases.get("i1"), is(0));
        assertThat(bases.get("i2"), is(5));


    }

}
